@@ -43,7 +43,6 @@ class RockerCoreTest(unittest.TestCase):
     def test_list_plugins(self):
         plugins_found = list_plugins()
         plugin_names = plugins_found.keys()
-        self.assertTrue('pulse' in plugin_names)
         self.assertTrue('home' in plugin_names)
 
     def test_get_version(self):
@@ -116,7 +115,7 @@ class RockerCoreTest(unittest.TestCase):
         self.assertIn('non-interactive', help_str)
         self.assertIn('--extension-blacklist', help_str)
 
-        active_extensions = extension_manager.get_active_extensions({'container_name': True, 'pulse': True, 'extension_blacklist': ['pulse']})
+        active_extensions = extension_manager.get_active_extensions({'container_name': True, 'home': True, 'extension_blacklist': ['home']})
         self.assertEqual(len(active_extensions), 1)
         self.assertEqual(active_extensions[0].get_name(), 'container_name')
 
